# Observables

```eval_rst
.. currentmodule:: baggianalysis.core

.. autosummary::
    :nosignatures:

    BondOrderParameters
    ClusterList
    CollectiveISF
    ConvexHull
    FormFactor
    MSD
    PoreSize
    RDF
    SelfISF
    StructureFactor
    
.. autoclass:: BondOrderParameters

.. autoclass:: ClusterList

.. autoclass:: CollectiveISF
    
.. autoclass:: ConvexHull
    
.. autoclass:: ConvexHullResult
    
.. autoclass:: ConvexHullTriangle

.. autoclass:: GyrationRadius

.. autoclass:: FormFactor

.. autoclass:: MSD

.. autoclass:: ParticleAutocorrelation
    
.. autoclass:: PoreSize
    
.. autoclass:: RDF

.. autoclass:: SelfISF
    
.. autoclass:: StructureFactor
    
.. autoclass:: DestructuredStructureFactor
```
